==> antlr-java-parser-1.0.5-sources.jar: com/github/antlrjavaparser/adapter/ElementValuePairsContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.Node;
import com.github.antlrjavaparser.api.expr.MemberValuePair;

import java.util.LinkedList;
import java.util.List;

public class ElementValuePairsContextAdapter implements Adapter<List<MemberValuePair>, Java7Parser.ElementValuePairsContext> {
    public List<MemberValuePair> adapt(Java7Parser.ElementValuePairsContext context) {

        /*
        elementValuePairs
            :   elementValuePair
                (COMMA elementValuePair
                )*
            ;
         */

        List<MemberValuePair> memberValuePairList = new LinkedList<MemberValuePair>();
        for (Java7Parser.ElementValuePairContext elementValuePairContext : context.elementValuePair()) {
            memberValuePairList.add(Adapters.getElementValuePairContextAdapter().adapt(elementValuePairContext));
        }

        return memberValuePairList;
    }
}

==> antlr-java-parser-1.0.12-sources.jar: com/github/antlrjavaparser/adapter/ElementValuePairsContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.Node;
import com.github.antlrjavaparser.api.expr.MemberValuePair;

import java.util.LinkedList;
import java.util.List;

public class ElementValuePairsContextAdapter implements Adapter<List<MemberValuePair>, Java7Parser.ElementValuePairsContext> {
    public List<MemberValuePair> adapt(Java7Parser.ElementValuePairsContext context, AdapterParameters adapterParameters) {

        /*
        elementValuePairs
            :   elementValuePair
                (COMMA elementValuePair
                )*
            ;
         */

        List<MemberValuePair> memberValuePairList = new LinkedList<MemberValuePair>();
        for (Java7Parser.ElementValuePairContext elementValuePairContext : context.elementValuePair()) {
            memberValuePairList.add(Adapters.getElementValuePairContextAdapter().adapt(elementValuePairContext, adapterParameters));
        }

        return memberValuePairList;
    }
}
